`dcmri` is a Python toolbox for dynamic MRI during contrast agent injection.

For more detail please see the
[documentation](https://qib-sheffield.github.io/dcmri/).

> **_PLEASE NOTE:_** ``dcmri`` is developed in public, however it is a work  
>       in progress and **not yet sufficiently stable for wider use**.
